@@ -15,7 +15,7 @@ async def _get_fqdns(fqdn: str, protocol: int) -> List[str]:
         result = socket.getaddrinfo(
             host=fqdn,
             port=None,
-            family=socket.AF_INET if protocol == 4 else socket.AF_INET6,
+            family=protocol,
             proto=socket.IPPROTO_IP,
             flags=socket.AI_NUMERICSERV | socket.AI_ADDRCONFIG | socket.AI_PASSIVE,
         )
