@@ -33,7 +33,7 @@ async def load_pip_versions(hub):
                 reqs[name] = version
     else:
         ret = await hub.exec.cmd.run(
-            [sys.executable, "-m", "pip", "show", "idem-darwin"]
+            [sys.executable, "-m", "pip", "show", "idem-linux"]
         )
         for line in ret.stdout.splitlines():
             if line.startswith("Requires:"):
@@ -63,7 +63,7 @@ async def load_pip_versions(hub):
 
             # pip is agnostic about case so we will prefer lower
             name = name.lower()
-            if name in reqs:
+            if name in reqs or name.startswith("idem") or name.startswith("pop"):
                 modules[name] = version
 
         hub.corn.CORN.requirement_versions = modules
